@@ -1,7 +1,7 @@
 import os
 
-from src.kdb_python import FolderSettings
-from src.kdb_python.common.utils import OS
+from kdb_python import FolderSettings
+from kdb_python.common.utils import OS
 
 SUFFIX_WIN32 = "_win32.exe"
 SUFFIX_WIN64 = "_win64.exe"
