@@ -23,13 +23,13 @@ from selenium.webdriver.firefox.service import Service as FirefoxService
 from selenium.webdriver.ie.options import Options as IEOptions, ElementScrollBehavior
 from selenium.webdriver.ie.service import Service as IEService
 
-from src import kdb_python
-from src.kdb_python import FolderSettings
-from src.kdb_python.common.config_parser import ConfigParser
-from src.kdb_python.common.constants import ErrorMessage
-from src.kdb_python.common.mobile_manager import MobileManager, get_device_info
-from src.kdb_python.common.utils import DeviceType, WebDriverUtil, OS, CommandLine, FileUtil
-from src.kdb_python.config.settings import ChromeSettings, FirefoxSettings, DriverSettings, IESettings, EdgeSettings
+import kdb_python
+from kdb_python import FolderSettings
+from kdb_python.common.config_parser import ConfigParser
+from kdb_python.common.constants import ErrorMessage
+from kdb_python.common.mobile_manager import MobileManager, get_device_info
+from kdb_python.common.utils import DeviceType, WebDriverUtil, OS, CommandLine, FileUtil
+from kdb_python.config.settings import ChromeSettings, FirefoxSettings, DriverSettings, IESettings, EdgeSettings
 
 
 def _get_proxy(proxy_name):
